@@ -1,11 +1,14 @@
 package Catalyst::Controller::Validation::DFV;
-$Catalyst::Controller::Validation::DFV::VERSION = '0.0.1';
+# vim: ts=8 sts=4 et sw=4 sr sta
 use strict;
 use warnings;
 
+use version; our $VERSION = qv(0.0.2)->numify;
+
 use base 'Catalyst::Controller';
 
 use Carp;
+use Data::Dump qw(pp);
 use Data::FormValidator '4.50';
 use Data::FormValidator::Constraints qw(:closures);
 
@@ -23,8 +26,6 @@ sub form_check :Private {
     return;
 }
 
-
-
 sub add_form_invalid :Private {
     my ($self, $c, $invalid_key, $invalid_value) = @_;
 
@@ -77,19 +78,18 @@ sub refill_form :Private {
 }
 
 1;
-# ABSTRACT: Form validation and refilling
+
+__END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Catalyst::Controller::Validation::DFV - Form validation and refilling
+Catalyst::Controller::Validation::DFV - check form data
 
-=head1 VERSION
+=head1 SUMMARY
 
-version 0.0.1
+Form-validation using a Catalyst controller and Data::FormValidator
 
 =head1 SYNOPSIS
 
@@ -149,47 +149,18 @@ version 0.0.1
         $c->forward('refill_form');
     }
 
-=head1 DESCRIPTION
-
-Form-validation using a Catalyst controller and Data::FormValidator
-
-=head1 Methods
-
-=head2 add_form_invalid
-
-=head2 validation_errors_to_html
-
-=head2 refill_form
-
 =head1 EXAMPLES
 
 There are L<Template::Toolkit> file examples in the examples/ directory of
 this distribution.
 
-=begin markdown
-
-## BUILD STATUS
-
-### master
-
-[![Build status](https://badge.buildkite.com/a51523ccfc452014358d9666ac0a51ca30bc409da860c34b7d.svg)](https://buildkite.com/chizography/catalyst-validation-dfv)
-
-=end markdown
-
 =head1 AUTHOR
 
-Chisel <chisel@chizography.net>
+Chisel Wright C<< <chiselwright@users.berlios.de> >>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 LICENSE
 
-This software is copyright (c) 2016 by Chisel Wright.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This library is free software, you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
-
-__END__
-
-
-# vim: ts=8 sts=4 et sw=4 sr sta
